@@ -17,4 +17,9 @@ def run(package, noisy, clean, config):
     if clean:
         eval_prog_args.append("-c")
 
-    return subprocess.call(["ssh", "-t", config.host, eval_prog, " ".join(eval_prog_args), target], stdout=sys.stdout, stderr=sys.stderr)
\ No newline at end of file
+    p = subprocess.Popen(["ssh", "-t", config.host, eval_prog, " ".join(eval_prog_args), target], 1, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    while True:
+        line = p.stdout.readline()
+        if not line or line == ENDLINE:
+            break
+        sys.stdout.write(line)
\ No newline at end of file
